init:				 ;Initiate Variables
;*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_
; File: ACO SplashLight - White 09092021.bas
; Author: Cody Dean Fatka
; Based on: Fatka's Flashlight Code and Fatka_601977_Lab3.c
; Created:
; 	V001 Est. 05/04/2017 "May the 4th Be With You" 11:11PM - 1:25AM
; 	V001 Author: Cody Dean Fatka 
; 	V002 Est. 05/14/2017 	12:02AM - 12:55AM
; 	V003 Est. 05/16/2017 	3:00PM  - 5:00PM
;     V004 Est. 05/22/2017	9:00AM  - 11:15AM
;     V005 Est. 06/03/2017	11:00PM - 1:30AM
;     V006 Est. 06/12/2017 	2:15PM  - 4:00PM (MPLABX to PICAXE EDITOR)
;     V007 Est. 06/12/2017	4:00PM  - 5:00PM
;     V008 Est. 06/14/2017	4:15PM  - 5:00PM
;	V009 Est. 06/23/2017	3:00PM  - 5:00PM (Yellow LED Added)
;	V010 Est. 06/26/2017	1:00PM  - 5:00PM (Code Finalized and Commented)
;     V011 Est. 09/09/2021    5:55PM           (Code Released)
; 
;*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_
;............(?`'?.                      /
;..............(?'?(?'?............_/)/)/
;...............(?'?.(?'?.......((..../((
;................(?`'?(?'?...((.)..(. ? /)
;.................(?`'?.(?'((.)....|\_/
;.....,,,~????`'?(_??(_.)......|
;...(((./...........................)__
;..((((.\......),,...........(...../__`\
;..))))..\ . .//...???????' \.../... / /
;.(((...../ .// .............. | ./.....\/
;.))).....| ||.................| |...........???
;((........) \\.................) \...........\|/
;.^^^^.""'"'.^^^^^^^..""".^^^^.""""
;*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_
; 
; Purpose:
;	To activate a red light when water contacts probes.
; 
; Summary:
;	Initiate microcontroller, inputs and variables
;	Wait for signal input
;	If Yes, Cycle thru red loop
; 	If no, continue to wait for input
;		
;		Start colored LED sequence (RGBY)
; Start a Counter so Sequence can be on for 2 minutes (#times to loop (2))
;	After one sequence, check input signal status	
;		If input = Yes
;			Then Add to Counter (To extend time of sequence to 2 minutes)
;		If input = No
;			Then continue to run Sequence.
;	After sequence ends, go to waiting for input signal
;
; Set internal Oscillator Frequency
setfreq m8; sets osc freq to 8MHz (Higher than 4MHz default where flicker in PWM)

; Set Ports to Input/Output
let dirsc = %00010111   ; To convert the pins on port C either Input or Output
;1 output
;0 input
				; Sets C0, C1, C2, C4 to outputs (Er, X, Eb, Pout)
				; Sets C3, C5 to inputs (Input Only, ProgIn)
let dirsb = %00111111; Sets B0, B1, B2, B3, B4, B5 to outputs 
;1 output
;0 input

; Set Ports to High/Low
low B.1, B.2, B.3, B.4, B.5;   ; Sets Pins Low, only high when needed
low C.0, C.1, C.2			 ; Sets Pins Low, only high when needed
high C.4                ; pin3 used for power to water signal, always high
; Sets Unused, Yellow, Unused, Green, Unused/ Red, Unused, Blue Ports Off
symbol Counter   = b0   ; Sets variable b0 to be called Counter for PWM 
symbol RED_LED   =C.0   ; Red LED on C.0 or pin7
symbol GREEN_LED =B.4   ; Green LED on B.4 or pin9
symbol BLUE_LED  =C.2   ; Blue LED on C.2 or pin5
symbol YELLOW_LED=B.2   ; Yellow LED on B.2 or pin 11
symbol InputSig  =C.3;  ; pin4 Input Only, used for water signal 
	
				; pin1 is VDD (1.9V to 5.5V, 3.3V will be regulated)
                        ; pin2 is prog in  C.5 Input Only
				; (22KOhm to AUX-b then 10KOhm from AUX-b to GND)
				; pin3 is C.4, I/O, Touch, ADC
				; pin4 is C.3, Input Only
				; pin5 is C.2, Blue LED, PWM, hpwmA, KB CLK, I/O
				; pin6 is C.1, I/O, hpwmB, KB DATA
				; pin7 is C.0, Red LED Enable, PWM, hpwmC, I/O, ADC, Touch
				; pin8 is B.5, I/O, ADC, hpwmD, Touch
				; pin9 is B.4, Green LED Enable, PWM, I/O, ADC, Touch, HI2C SDA
				; pin10 is B.3, I/O, ADC, Touch, HI2C SCL
				; pin11 is B.2, Yellow LED Enable, PWM, I/O, ADC, Touch, SRQ
				; pin12 is B.1, I/O, ADC, Touch, SRI, HSERIN 
				; pin13 is B.0, PROG Out, Out Only HSEROUT, DAC, prog out (to AUX-a) (AUX-c is gnd)
				; pin 14 is GND, 0 Volts
				; ------\_/-----\__/-----\
				; ------/-\-----/--\-----/  (AUX TIP)
				;  A (1)    B (2)     C (3) (Tip)
				; 
;1	1	PICAXE Microcontroller PICAXE-14M2-SM
;2	1	Capacitor 1 (PIC Vdd to Vss) 0.1uF
;3	1	Programming Input (AUX Stereo Input)
;4	1	Resistor 1 (PROG) 10Kohm
;5	1	Resistor 2 (PROG) 22Kohm
;6	3	LED (RGB) -Common Anode
;7	2	LED Yellow
;8	1	Transistor 1 (Red LED) NPN
;9	1	Transistor 2 (Green LED) NPN
;10	1	Transistor 3 (Blue LED) NPN
;11	1	Transistor 4 (Yellow LED) NPN
;12	1	Resistor 3 (Red LED)[14 Ohm]
;13	1	Resistor 4 (Green LED)[1 Ohm]
;14	1	Resistor 5 (Blue LED)[1 Ohm]
;15	1	Resistor 6 (Yellow LED)[33 Ohm]
;16	1	Voltage Regulator (3.3 Volts, LDO)
;17	1	Capacitor 2 (Vreg Vin) 10uF
;18	1	Capacitor 3 (Vreg Vout) 10uF
;19	2	Battery LiPO 3.7V with charging circuit
;20	1	Diode 1 (Battery Protect)
;21	1	Battery Charging Input - USB Type C
;22	2	Stainless Steel Probe
;23	1	Resistor 7 (Signal Input to GND) 3.3Mohm
;24	1	Programming Cable for PICAXE
;25   2     Charging Cables for USB Type C
;26	1	PICAXE CODE - PICAXE Editor - See Cody Fatka 09/2021

pause 500 ; Lets Chip Initiate and Settle

main0:				 ;Main Program

low B.1, B.2, B.3, B.4, B.5	 ; Sets Pins Low, only high when needed  
low C.0, C.1, C.2			 ; Sets Pins Low, only high when needed
pause 20 ; Lets pins settle to off position (20 mSec)
; (RED OFF, GREEN OFF, BLUE OFF, YELLOW OFF) (POWER ON FOR SIGNAL)

; Check for Signal
if pinC.3 = 1 then 		 ; Checks C.3 or pin 4 (Signal Input)
					 ; Fade Red ON, then Fade other colors ON
for b3 = 0 to 249 step 1       ; define loop for b3 times to step from 0 to 255
	PWM RED_LED, b3, 1       ; Pulse Width Modulation on Red LED, duty, step                   
next b3 				 ; Goes to next b3 number and to top of for loop
PWM RED_LED, 251, 20 ; These are to slowly transisition from fade on to on
PWM RED_LED, 252, 20 ; If not, you can tell ramp, ramp, ramp, on (pops)
PWM RED_LED, 253, 20
PWM RED_LED, 254, 20 ; Made By Cody Fatka slowed down to ramp without flicker

; Keep RED On
; (RED ON, GREEN OFF, BLUE OFF, YELLOW OFF)

high RED_LED
 pause 500				 ; keep red on by itself for 0.5sec
 
; Red is on
; Fade Blue on
for b3 = 0 to 255 step 2       ; define loop for b3 times to step from 0 to 255
	PWM BLUE_LED, b3, 1       ; Pulse Width Modulation on Red LED, duty, step                   
next b3 				 ; Goes to next b3 number and to top of for loo
high BLUE_LED
pause 500
; (RED ON, GREEN OFF, BLUE ON, YELLOW OFF)
; Fade Green on
for b3 = 0 to 255 step 2       ; define loop for b3 times to step from 0 to 255
	PWM GREEN_LED, b3, 1       ; Pulse Width Modulation on Red LED, duty, step                   
next b3 				 ; Goes to next b3 number and to top of for loo
high GREEN_LED
; (RED ON, GREEN ON, BLUE ON, YELLOW OFF)
; Fade Yellow on
for b3 = 0 to 255 step 2       ; define loop for b3 times to step from 0 to 255
	PWM YELLOW_LED, b3, 1       ; Pulse Width Modulation on Red LED, duty, step                   
next b3 				 ; Goes to next b3 number and to top of for loo
high YELLOW_LED
; (RED ON, GREEN ON, BLUE ON, YELLOW ON)

for b2 = 3 downto 0 step 1; repeates next lines "b2" times (changed to 3 09/09/2021 - over 2 min)
; Red and Blue and Green and Yellow is on
	
;_______________________			
; LOOP STARTING	;
; Red is on already (Faded On)     ;
; Keep Red On
; Fade Blue on
; Keep Blue on
; Fade Green on
; Keep Green on
; Fade Yellow on
; Keep Yellow on
; (R/G/B/Y make white)
; keep on
; REPEAT                 ;
;_______________________;


high RED_LED, BLUE_LED, GREEN_LED, YELLOW_LED

 pause 60000				 ; pause (mS) 1000 = 1 Second , 60000 = 1 minute

if pinC.3 = 1 then 		 ; Checks C.3 or pin 4 (Signal Input)
	b2 = b2+1			 ; If Input is still on, keep loop going	
 Endif ; "else" do nothing and let b2 expire, poor b2, no more colors

next b2 ; goes to "For b2=2 " and decreases b2 by "step" (1)
        ; then to b2 = 1, then if b2 = 2, then stops
  	; internal check during red light to see if signal is present
	; if signal is present, add one to the b2 "counter"
      ; to extend time so no interruption in red color.

Endif ; "Else" Do nothing (wait for input signal)

goto main0 ; loop back / jump back to the start

;*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_
; Made By Cody Fatka, Circuit diagnostics and consolidation by Joe Venters
; ACO Building Drainage Research and Development Department
;*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_
;............(?`'?.                      /
;..............(?'?(?'?............_/)/)/
;...............(?'?.(?'?.......((..../((
;................(?`'?(?'?...((.)..(. ? /)
;.................(?`'?.(?'((.)....|\_/
;.....,,,~????`'?(_??(_.)......|
;...(((./...........................)__
;..((((.\......),,...........(...../__`\
;..))))..\ . .//...???????' \.../... / /
;.(((...../ .// .............. | ./.....\/
;.))).....| ||.................| |...........???
;((........) \\.................) \...........\|/
;.^^^^.""'"'.^^^^^^^..""".^^^^.""""
;*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_*_



End                      ;The end of the main program, Cody Fatka 09/09/2021